"""This module contains the general information for FirmwarePolicy ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FirmwarePolicyConsts():
    DEPLOYMENT_MODE_IMMEDIATE = "immediate"
    DEPLOYMENT_MODE_MAINT_POLICY = "maint-policy"
    DEPLOYMENT_MODE_TIMER_AUTOMATIC = "timer-automatic"
    DEPLOYMENT_MODE_USER_ACK = "user-ack"
    HONOR_LS_MAINT_POLICY_FALSE = "false"
    HONOR_LS_MAINT_POLICY_NO = "no"
    HONOR_LS_MAINT_POLICY_TRUE = "true"
    HONOR_LS_MAINT_POLICY_YES = "yes"
    IGNORE_COMP_CHECK_FALSE = "false"
    IGNORE_COMP_CHECK_NO = "no"
    IGNORE_COMP_CHECK_TRUE = "true"
    IGNORE_COMP_CHECK_YES = "yes"
    INT_ID_NONE = "none"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    POLICY_OWNER_UNSPECIFIED = "unspecified"


class FirmwarePolicy(ManagedObject):
    """This is FirmwarePolicy class."""

    consts = FirmwarePolicyConsts()
    naming_props = set([])

    mo_meta = MoMeta("FirmwarePolicy", "firmwarePolicy", "fw-policy", VersionMeta.Version101a, "InputOutput", 0x3f, [], ["admin", "operations"], [u'orgDomainGroup'], [], [None])

    prop_meta = {
        "blade_version": MoPropertyMeta("blade_version", "bladeVersion", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "deployment_mode": MoPropertyMeta("deployment_mode", "deploymentMode", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["immediate", "maint-policy", "timer-automatic", "user-ack"], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x2, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "honor_ls_maint_policy": MoPropertyMeta("honor_ls_maint_policy", "honorLsMaintPolicy", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "ignore_comp_check": MoPropertyMeta("ignore_comp_check", "ignoreCompCheck", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "infra_version": MoPropertyMeta("infra_version", "infraVersion", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["local", "pending-policy", "policy", "unspecified"], []), 
        "rack_version": MoPropertyMeta("rack_version", "rackVersion", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "start_time": MoPropertyMeta("start_time", "startTime", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "bladeVersion": "blade_version", 
        "childAction": "child_action", 
        "deploymentMode": "deployment_mode", 
        "descr": "descr", 
        "dn": "dn", 
        "honorLsMaintPolicy": "honor_ls_maint_policy", 
        "ignoreCompCheck": "ignore_comp_check", 
        "infraVersion": "infra_version", 
        "intId": "int_id", 
        "name": "name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "rackVersion": "rack_version", 
        "rn": "rn", 
        "startTime": "start_time", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.blade_version = None
        self.child_action = None
        self.deployment_mode = None
        self.descr = None
        self.honor_ls_maint_policy = None
        self.ignore_comp_check = None
        self.infra_version = None
        self.int_id = None
        self.name = None
        self.policy_level = None
        self.policy_owner = None
        self.rack_version = None
        self.start_time = None
        self.status = None

        ManagedObject.__init__(self, "FirmwarePolicy", parent_mo_or_dn, **kwargs)




"""This module contains the general information for HcSupportedAdapterItem ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class HcSupportedAdapterItemConsts():
    pass


class HcSupportedAdapterItem(ManagedObject):
    """This is HcSupportedAdapterItem class."""

    consts = HcSupportedAdapterItemConsts()
    naming_props = set([u'itemId'])

    mo_meta = MoMeta("HcSupportedAdapterItem", "hcSupportedAdapterItem", "supported-adapter-[item_id]", VersionMeta.Version151a, "InputOutput", 0x7ff, [], ["admin"], [u'hcAdapterItem'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "item_id": MoPropertyMeta("item_id", "itemId", "ulong", VersionMeta.Version151a, MoPropertyMeta.NAMING, 0x4, None, None, None, [], []), 
        "item_protocol": MoPropertyMeta("item_protocol", "itemProtocol", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x8, 0, 510, None, [], []), 
        "item_ref_dn": MoPropertyMeta("item_ref_dn", "itemRefDn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x10, 0, 256, None, [], []), 
        "item_ref_id": MoPropertyMeta("item_ref_id", "itemRefId", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x20, 0, 256, None, [], []), 
        "item_ref_model": MoPropertyMeta("item_ref_model", "itemRefModel", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x40, 0, 510, None, [], []), 
        "item_vendor": MoPropertyMeta("item_vendor", "itemVendor", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x80, 0, 510, None, [], []), 
        "item_version": MoPropertyMeta("item_version", "itemVersion", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x100, 0, 510, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x200, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x400, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "itemId": "item_id", 
        "itemProtocol": "item_protocol", 
        "itemRefDn": "item_ref_dn", 
        "itemRefId": "item_ref_id", 
        "itemRefModel": "item_ref_model", 
        "itemVendor": "item_vendor", 
        "itemVersion": "item_version", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, item_id, **kwargs):
        self._dirty_mask = 0
        self.item_id = item_id
        self.child_action = None
        self.item_protocol = None
        self.item_ref_dn = None
        self.item_ref_id = None
        self.item_ref_model = None
        self.item_vendor = None
        self.item_version = None
        self.status = None

        ManagedObject.__init__(self, "HcSupportedAdapterItem", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ConfigAppImpactResponse ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ConfigAppImpactResponseConsts():
    PROFILE_TYPE_CHASSIS_PROFILE = "chassis-profile"
    PROFILE_TYPE_SERVICE_PROFILE = "service-profile"
    STATE_COMPLETE = "complete"
    STATE_LOST_VISIBILITY = "lost-visibility"
    STATE_NOT_STARTED = "not-started"
    STATE_SUSPEND = "suspend"
    STATE_TIMED_OUT = "timed-out"
    STATE_WAITING = "waiting"


class ConfigAppImpactResponse(ManagedObject):
    """This is ConfigAppImpactResponse class."""

    consts = ConfigAppImpactResponseConsts()
    naming_props = set([u'appConnectorId', u'sourceConnectorId'])

    mo_meta = MoMeta("ConfigAppImpactResponse", "configAppImpactResponse", "app-id-[app_connector_id]src-id-[source_connector_id]", VersionMeta.Version111a, "InputOutput", 0x1ff, [], ["read-only"], [u'configImpactAnalyzer'], [u'configUCImpact'], [None])

    prop_meta = {
        "app_connector_id": MoPropertyMeta("app_connector_id", "appConnectorId", "uint", VersionMeta.Version111a, MoPropertyMeta.NAMING, 0x2, None, None, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "impact_analyzer_id": MoPropertyMeta("impact_analyzer_id", "impactAnalyzerId", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "profile_type": MoPropertyMeta("profile_type", "profileType", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["chassis-profile", "service-profile"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []), 
        "source_connector_id": MoPropertyMeta("source_connector_id", "sourceConnectorId", "uint", VersionMeta.Version111a, MoPropertyMeta.NAMING, 0x40, None, None, None, [], []), 
        "state": MoPropertyMeta("state", "state", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["complete", "lost-visibility", "not-started", "suspend", "timed-out", "waiting"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "appConnectorId": "app_connector_id", 
        "childAction": "child_action", 
        "dn": "dn", 
        "impactAnalyzerId": "impact_analyzer_id", 
        "profileType": "profile_type", 
        "rn": "rn", 
        "sourceConnectorId": "source_connector_id", 
        "state": "state", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, app_connector_id, source_connector_id, **kwargs):
        self._dirty_mask = 0
        self.app_connector_id = app_connector_id
        self.source_connector_id = source_connector_id
        self.child_action = None
        self.impact_analyzer_id = None
        self.profile_type = None
        self.state = None
        self.status = None

        ManagedObject.__init__(self, "ConfigAppImpactResponse", parent_mo_or_dn, **kwargs)




"""This module contains the general information for EtherLossStats ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class EtherLossStatsConsts():
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class EtherLossStats(ManagedObject):
    """This is EtherLossStats class."""

    consts = EtherLossStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("EtherLossStats", "etherLossStats", "loss-stats", VersionMeta.Version111a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], [u'etherServerIntFIo'], [u'etherLossStatsHist'], [None])

    prop_meta = {
        "sqe_test": MoPropertyMeta("sqe_test", "SQETest", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "sqe_test_delta": MoPropertyMeta("sqe_test_delta", "SQETestDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "sqe_test_delta_avg": MoPropertyMeta("sqe_test_delta_avg", "SQETestDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "sqe_test_delta_max": MoPropertyMeta("sqe_test_delta_max", "SQETestDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "sqe_test_delta_min": MoPropertyMeta("sqe_test_delta_min", "SQETestDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "carrier_sense": MoPropertyMeta("carrier_sense", "carrierSense", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "carrier_sense_delta": MoPropertyMeta("carrier_sense_delta", "carrierSenseDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "carrier_sense_delta_avg": MoPropertyMeta("carrier_sense_delta_avg", "carrierSenseDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "carrier_sense_delta_max": MoPropertyMeta("carrier_sense_delta_max", "carrierSenseDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "carrier_sense_delta_min": MoPropertyMeta("carrier_sense_delta_min", "carrierSenseDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "excess_collision": MoPropertyMeta("excess_collision", "excessCollision", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "excess_collision_delta": MoPropertyMeta("excess_collision_delta", "excessCollisionDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "excess_collision_delta_avg": MoPropertyMeta("excess_collision_delta_avg", "excessCollisionDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "excess_collision_delta_max": MoPropertyMeta("excess_collision_delta_max", "excessCollisionDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "excess_collision_delta_min": MoPropertyMeta("excess_collision_delta_min", "excessCollisionDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "giants": MoPropertyMeta("giants", "giants", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "giants_delta": MoPropertyMeta("giants_delta", "giantsDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "giants_delta_avg": MoPropertyMeta("giants_delta_avg", "giantsDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "giants_delta_max": MoPropertyMeta("giants_delta_max", "giantsDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "giants_delta_min": MoPropertyMeta("giants_delta_min", "giantsDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "late_collision": MoPropertyMeta("late_collision", "lateCollision", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "late_collision_delta": MoPropertyMeta("late_collision_delta", "lateCollisionDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "late_collision_delta_avg": MoPropertyMeta("late_collision_delta_avg", "lateCollisionDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "late_collision_delta_max": MoPropertyMeta("late_collision_delta_max", "lateCollisionDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "late_collision_delta_min": MoPropertyMeta("late_collision_delta_min", "lateCollisionDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "multi_collision": MoPropertyMeta("multi_collision", "multiCollision", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "multi_collision_delta": MoPropertyMeta("multi_collision_delta", "multiCollisionDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "multi_collision_delta_avg": MoPropertyMeta("multi_collision_delta_avg", "multiCollisionDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "multi_collision_delta_max": MoPropertyMeta("multi_collision_delta_max", "multiCollisionDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "multi_collision_delta_min": MoPropertyMeta("multi_collision_delta_min", "multiCollisionDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "normalized_time_col": MoPropertyMeta("normalized_time_col", "normalizedTimeCol", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "single_collision": MoPropertyMeta("single_collision", "singleCollision", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "single_collision_delta": MoPropertyMeta("single_collision_delta", "singleCollisionDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "single_collision_delta_avg": MoPropertyMeta("single_collision_delta_avg", "singleCollisionDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "single_collision_delta_max": MoPropertyMeta("single_collision_delta_max", "singleCollisionDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "single_collision_delta_min": MoPropertyMeta("single_collision_delta_min", "singleCollisionDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "stats_reported": MoPropertyMeta("stats_reported", "statsReported", "int", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "symbol": MoPropertyMeta("symbol", "symbol", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "symbol_delta": MoPropertyMeta("symbol_delta", "symbolDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "symbol_delta_avg": MoPropertyMeta("symbol_delta_avg", "symbolDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "symbol_delta_max": MoPropertyMeta("symbol_delta_max", "symbolDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "symbol_delta_min": MoPropertyMeta("symbol_delta_min", "symbolDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
    }

    prop_map = {
        "SQETest": "sqe_test", 
        "SQETestDelta": "sqe_test_delta", 
        "SQETestDeltaAvg": "sqe_test_delta_avg", 
        "SQETestDeltaMax": "sqe_test_delta_max", 
        "SQETestDeltaMin": "sqe_test_delta_min", 
        "carrierSense": "carrier_sense", 
        "carrierSenseDelta": "carrier_sense_delta", 
        "carrierSenseDeltaAvg": "carrier_sense_delta_avg", 
        "carrierSenseDeltaMax": "carrier_sense_delta_max", 
        "carrierSenseDeltaMin": "carrier_sense_delta_min", 
        "childAction": "child_action", 
        "dn": "dn", 
        "excessCollision": "excess_collision", 
        "excessCollisionDelta": "excess_collision_delta", 
        "excessCollisionDeltaAvg": "excess_collision_delta_avg", 
        "excessCollisionDeltaMax": "excess_collision_delta_max", 
        "excessCollisionDeltaMin": "excess_collision_delta_min", 
        "giants": "giants", 
        "giantsDelta": "giants_delta", 
        "giantsDeltaAvg": "giants_delta_avg", 
        "giantsDeltaMax": "giants_delta_max", 
        "giantsDeltaMin": "giants_delta_min", 
        "intervals": "intervals", 
        "lateCollision": "late_collision", 
        "lateCollisionDelta": "late_collision_delta", 
        "lateCollisionDeltaAvg": "late_collision_delta_avg", 
        "lateCollisionDeltaMax": "late_collision_delta_max", 
        "lateCollisionDeltaMin": "late_collision_delta_min", 
        "multiCollision": "multi_collision", 
        "multiCollisionDelta": "multi_collision_delta", 
        "multiCollisionDeltaAvg": "multi_collision_delta_avg", 
        "multiCollisionDeltaMax": "multi_collision_delta_max", 
        "multiCollisionDeltaMin": "multi_collision_delta_min", 
        "normalizedTimeCol": "normalized_time_col", 
        "rn": "rn", 
        "singleCollision": "single_collision", 
        "singleCollisionDelta": "single_collision_delta", 
        "singleCollisionDeltaAvg": "single_collision_delta_avg", 
        "singleCollisionDeltaMax": "single_collision_delta_max", 
        "singleCollisionDeltaMin": "single_collision_delta_min", 
        "statsReported": "stats_reported", 
        "status": "status", 
        "suspect": "suspect", 
        "symbol": "symbol", 
        "symbolDelta": "symbol_delta", 
        "symbolDeltaAvg": "symbol_delta_avg", 
        "symbolDeltaMax": "symbol_delta_max", 
        "symbolDeltaMin": "symbol_delta_min", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.sqe_test = None
        self.sqe_test_delta = None
        self.sqe_test_delta_avg = None
        self.sqe_test_delta_max = None
        self.sqe_test_delta_min = None
        self.carrier_sense = None
        self.carrier_sense_delta = None
        self.carrier_sense_delta_avg = None
        self.carrier_sense_delta_max = None
        self.carrier_sense_delta_min = None
        self.child_action = None
        self.excess_collision = None
        self.excess_collision_delta = None
        self.excess_collision_delta_avg = None
        self.excess_collision_delta_max = None
        self.excess_collision_delta_min = None
        self.giants = None
        self.giants_delta = None
        self.giants_delta_avg = None
        self.giants_delta_max = None
        self.giants_delta_min = None
        self.intervals = None
        self.late_collision = None
        self.late_collision_delta = None
        self.late_collision_delta_avg = None
        self.late_collision_delta_max = None
        self.late_collision_delta_min = None
        self.multi_collision = None
        self.multi_collision_delta = None
        self.multi_collision_delta_avg = None
        self.multi_collision_delta_max = None
        self.multi_collision_delta_min = None
        self.normalized_time_col = None
        self.single_collision = None
        self.single_collision_delta = None
        self.single_collision_delta_avg = None
        self.single_collision_delta_max = None
        self.single_collision_delta_min = None
        self.stats_reported = None
        self.status = None
        self.suspect = None
        self.symbol = None
        self.symbol_delta = None
        self.symbol_delta_avg = None
        self.symbol_delta_max = None
        self.symbol_delta_min = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "EtherLossStats", parent_mo_or_dn, **kwargs)




"""This module contains the general information for StatsThresholdClass ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class StatsThresholdClassConsts():
    INT_ID_NONE = "none"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    POLICY_OWNER_UNSPECIFIED = "unspecified"
    STATS_CLASS_ID_ADAPTOR_ETH_PORT_BY_SIZE_LARGE_STATS = "adaptorEthPortBySizeLargeStats"
    STATS_CLASS_ID_ADAPTOR_ETH_PORT_BY_SIZE_SMALL_STATS = "adaptorEthPortBySizeSmallStats"
    STATS_CLASS_ID_ADAPTOR_ETH_PORT_ERR_STATS = "adaptorEthPortErrStats"
    STATS_CLASS_ID_ADAPTOR_ETH_PORT_MCAST_STATS = "adaptorEthPortMcastStats"
    STATS_CLASS_ID_ADAPTOR_ETH_PORT_OUTSIZED_STATS = "adaptorEthPortOutsizedStats"
    STATS_CLASS_ID_ADAPTOR_ETH_PORT_STATS = "adaptorEthPortStats"
    STATS_CLASS_ID_ADAPTOR_ETHER_IF_STATS = "adaptorEtherIfStats"
    STATS_CLASS_ID_ADAPTOR_FC_IF_EVENT_STATS = "adaptorFcIfEventStats"
    STATS_CLASS_ID_ADAPTOR_FC_IF_FC4_STATS = "adaptorFcIfFC4Stats"
    STATS_CLASS_ID_ADAPTOR_FC_IF_FRAME_STATS = "adaptorFcIfFrameStats"
    STATS_CLASS_ID_ADAPTOR_FC_PORT_STATS = "adaptorFcPortStats"
    STATS_CLASS_ID_ADAPTOR_HBAVNIC_STATS = "adaptorHBAVnicStats"
    STATS_CLASS_ID_ADAPTOR_MENLO_BASE_ERROR_STATS = "adaptorMenloBaseErrorStats"
    STATS_CLASS_ID_ADAPTOR_MENLO_DCE_PORT_STATS = "adaptorMenloDcePortStats"
    STATS_CLASS_ID_ADAPTOR_MENLO_ETH_ERROR_STATS = "adaptorMenloEthErrorStats"
    STATS_CLASS_ID_ADAPTOR_MENLO_ETH_STATS = "adaptorMenloEthStats"
    STATS_CLASS_ID_ADAPTOR_MENLO_FC_ERROR_STATS = "adaptorMenloFcErrorStats"
    STATS_CLASS_ID_ADAPTOR_MENLO_FC_STATS = "adaptorMenloFcStats"
    STATS_CLASS_ID_ADAPTOR_MENLO_HOST_PORT_STATS = "adaptorMenloHostPortStats"
    STATS_CLASS_ID_ADAPTOR_MENLO_MCPU_ERROR_STATS = "adaptorMenloMcpuErrorStats"
    STATS_CLASS_ID_ADAPTOR_MENLO_MCPU_STATS = "adaptorMenloMcpuStats"
    STATS_CLASS_ID_ADAPTOR_MENLO_NET_EG_STATS = "adaptorMenloNetEgStats"
    STATS_CLASS_ID_ADAPTOR_MENLO_NET_IN_STATS = "adaptorMenloNetInStats"
    STATS_CLASS_ID_ADAPTOR_MENLO_QERROR_STATS = "adaptorMenloQErrorStats"
    STATS_CLASS_ID_ADAPTOR_MENLO_QSTATS = "adaptorMenloQStats"
    STATS_CLASS_ID_ADAPTOR_NICVNIC_STATS = "adaptorNICVnicStats"
    STATS_CLASS_ID_ADAPTOR_VNIC_STATS = "adaptorVnicStats"
    STATS_CLASS_ID_COMPUTE_IOHUB_ENV_STATS = "computeIOHubEnvStats"
    STATS_CLASS_ID_COMPUTE_MB_POWER_STATS = "computeMbPowerStats"
    STATS_CLASS_ID_COMPUTE_MB_TEMP_STATS = "computeMbTempStats"
    STATS_CLASS_ID_COMPUTE_PCIE_FATAL_COMPLETION_STATS = "computePCIeFatalCompletionStats"
    STATS_CLASS_ID_COMPUTE_PCIE_FATAL_PROTOCOL_STATS = "computePCIeFatalProtocolStats"
    STATS_CLASS_ID_COMPUTE_PCIE_FATAL_RECEIVE_STATS = "computePCIeFatalReceiveStats"
    STATS_CLASS_ID_COMPUTE_PCIE_FATAL_STATS = "computePCIeFatalStats"
    STATS_CLASS_ID_COMPUTE_RACK_UNIT_MB_TEMP_STATS = "computeRackUnitMbTempStats"
    STATS_CLASS_ID_EQUIPMENT_CHASSIS_STATS = "equipmentChassisStats"
    STATS_CLASS_ID_EQUIPMENT_FAN_MODULE_STATS = "equipmentFanModuleStats"
    STATS_CLASS_ID_EQUIPMENT_FAN_STATS = "equipmentFanStats"
    STATS_CLASS_ID_EQUIPMENT_FEX_ENV_STATS = "equipmentFexEnvStats"
    STATS_CLASS_ID_EQUIPMENT_FEX_POWER_SUMMARY = "equipmentFexPowerSummary"
    STATS_CLASS_ID_EQUIPMENT_FEX_PSU_INPUT_STATS = "equipmentFexPsuInputStats"
    STATS_CLASS_ID_EQUIPMENT_IOCARD_STATS = "equipmentIOCardStats"
    STATS_CLASS_ID_EQUIPMENT_NETWORK_ELEMENT_FAN_STATS = "equipmentNetworkElementFanStats"
    STATS_CLASS_ID_EQUIPMENT_PSU_INPUT_STATS = "equipmentPsuInputStats"
    STATS_CLASS_ID_EQUIPMENT_PSU_OUTPUT_STATS = "equipmentPsuOutputStats"
    STATS_CLASS_ID_EQUIPMENT_PSU_STATS = "equipmentPsuStats"
    STATS_CLASS_ID_EQUIPMENT_RACK_UNIT_FAN_STATS = "equipmentRackUnitFanStats"
    STATS_CLASS_ID_EQUIPMENT_RACK_UNIT_PSU_STATS = "equipmentRackUnitPsuStats"
    STATS_CLASS_ID_EQUIPMENT_SIOC_TEMP_STATS = "equipmentSiocTempStats"
    STATS_CLASS_ID_ETHER_ERR_STATS = "etherErrStats"
    STATS_CLASS_ID_ETHER_FCOE_INTERFACE_STATS = "etherFcoeInterfaceStats"
    STATS_CLASS_ID_ETHER_LOSS_STATS = "etherLossStats"
    STATS_CLASS_ID_ETHER_PAUSE_STATS = "etherPauseStats"
    STATS_CLASS_ID_ETHER_RX_STATS = "etherRxStats"
    STATS_CLASS_ID_ETHER_TX_STATS = "etherTxStats"
    STATS_CLASS_ID_FC_ERR_STATS = "fcErrStats"
    STATS_CLASS_ID_FC_STATS = "fcStats"
    STATS_CLASS_ID_MEMORY_ARRAY_ENV_STATS = "memoryArrayEnvStats"
    STATS_CLASS_ID_MEMORY_BUFFER_UNIT_ENV_STATS = "memoryBufferUnitEnvStats"
    STATS_CLASS_ID_MEMORY_ERROR_STATS = "memoryErrorStats"
    STATS_CLASS_ID_MEMORY_RUNTIME = "memoryRuntime"
    STATS_CLASS_ID_MEMORY_UNIT_ENV_STATS = "memoryUnitEnvStats"
    STATS_CLASS_ID_POWER_GROUP_STATS = "powerGroupStats"
    STATS_CLASS_ID_PROCESSOR_ENV_STATS = "processorEnvStats"
    STATS_CLASS_ID_PROCESSOR_ERROR_STATS = "processorErrorStats"
    STATS_CLASS_ID_PROCESSOR_RUNTIME = "processorRuntime"
    STATS_CLASS_ID_STORAGE_CTRL_STORAGE_STATS = "storageCtrlStorageStats"
    STATS_CLASS_ID_STORAGE_DISK_ENV_STATS = "storageDiskEnvStats"
    STATS_CLASS_ID_STORAGE_HDD_MOTHER_BOARD_TEMP_STATS = "storageHddMotherBoardTempStats"
    STATS_CLASS_ID_STORAGE_NVME_STATS = "storageNvmeStats"
    STATS_CLASS_ID_STORAGE_SSD_HEALTH_STATS = "storageSsdHealthStats"
    STATS_CLASS_ID_STORAGE_STORAGE_STATS = "storageStorageStats"
    STATS_CLASS_ID_SW_CARD_ENV_STATS = "swCardEnvStats"
    STATS_CLASS_ID_SW_ENV_STATS = "swEnvStats"
    STATS_CLASS_ID_SW_SYSTEM_STATS = "swSystemStats"
    STATS_CLASS_ID_UNSPECIFIED = "unspecified"


class StatsThresholdClass(ManagedObject):
    """This is StatsThresholdClass class."""

    consts = StatsThresholdClassConsts()
    naming_props = set([u'statsClassId'])

    mo_meta = MoMeta("StatsThresholdClass", "statsThresholdClass", "[stats_class_id]", VersionMeta.Version101a, "InputOutput", 0x7f, [], ["admin", "operations"], [u'statsThresholdPolicy'], [u'statsThr32Definition', u'statsThr64Definition', u'statsThrFloatDefinition'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x2, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["local", "pending-policy", "policy", "unspecified"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "stats_class_id": MoPropertyMeta("stats_class_id", "statsClassId", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x20, None, None, None, ["adaptorEthPortBySizeLargeStats", "adaptorEthPortBySizeSmallStats", "adaptorEthPortErrStats", "adaptorEthPortMcastStats", "adaptorEthPortOutsizedStats", "adaptorEthPortStats", "adaptorEtherIfStats", "adaptorFcIfEventStats", "adaptorFcIfFC4Stats", "adaptorFcIfFrameStats", "adaptorFcPortStats", "adaptorHBAVnicStats", "adaptorMenloBaseErrorStats", "adaptorMenloDcePortStats", "adaptorMenloEthErrorStats", "adaptorMenloEthStats", "adaptorMenloFcErrorStats", "adaptorMenloFcStats", "adaptorMenloHostPortStats", "adaptorMenloMcpuErrorStats", "adaptorMenloMcpuStats", "adaptorMenloNetEgStats", "adaptorMenloNetInStats", "adaptorMenloQErrorStats", "adaptorMenloQStats", "adaptorNICVnicStats", "adaptorVnicStats", "computeIOHubEnvStats", "computeMbPowerStats", "computeMbTempStats", "computePCIeFatalCompletionStats", "computePCIeFatalProtocolStats", "computePCIeFatalReceiveStats", "computePCIeFatalStats", "computeRackUnitMbTempStats", "equipmentChassisStats", "equipmentFanModuleStats", "equipmentFanStats", "equipmentFexEnvStats", "equipmentFexPowerSummary", "equipmentFexPsuInputStats", "equipmentIOCardStats", "equipmentNetworkElementFanStats", "equipmentPsuInputStats", "equipmentPsuOutputStats", "equipmentPsuStats", "equipmentRackUnitFanStats", "equipmentRackUnitPsuStats", "equipmentSiocTempStats", "etherErrStats", "etherFcoeInterfaceStats", "etherLossStats", "etherPauseStats", "etherRxStats", "etherTxStats", "fcErrStats", "fcStats", "memoryArrayEnvStats", "memoryBufferUnitEnvStats", "memoryErrorStats", "memoryRuntime", "memoryUnitEnvStats", "powerGroupStats", "processorEnvStats", "processorErrorStats", "processorRuntime", "storageCtrlStorageStats", "storageDiskEnvStats", "storageHddMotherBoardTempStats", "storageNvmeStats", "storageSsdHealthStats", "storageStorageStats", "swCardEnvStats", "swEnvStats", "swSystemStats", "unspecified"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "intId": "int_id", 
        "name": "name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "rn": "rn", 
        "statsClassId": "stats_class_id", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, stats_class_id, **kwargs):
        self._dirty_mask = 0
        self.stats_class_id = stats_class_id
        self.child_action = None
        self.descr = None
        self.int_id = None
        self.name = None
        self.policy_level = None
        self.policy_owner = None
        self.status = None

        ManagedObject.__init__(self, "StatsThresholdClass", parent_mo_or_dn, **kwargs)




"""This module contains the general information for HcAdapterItem ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class HcAdapterItemConsts():
    ITEM_ERROR_CODE_ADAPTER_FW_VERSION_NOT_FOUND = "adapter-fw-version-not-found"
    ITEM_ERROR_CODE_ADAPTER_NOT_TAGGED = "adapter-not-tagged"
    ITEM_ERROR_CODE_DN_NOT_SPECIFIED = "dn-not-specified"
    ITEM_ERROR_CODE_DN_NOT_SUPPORTED = "dn-not-supported"
    ITEM_ERROR_CODE_INVALID_INPUT = "invalid-input"
    ITEM_ERROR_CODE_MISSING_DATA_IN_CATALOG = "missing-data-in-catalog"
    ITEM_ERROR_CODE_NO_MATCHING_SERVERS_FOUND = "no-matching-servers-found"
    ITEM_ERROR_CODE_NONE = "none"
    ITEM_ERROR_CODE_OS_NOT_TAGGED = "os-not-tagged"
    ITEM_ERROR_CODE_RETRY = "retry"
    ITEM_ERROR_CODE_TARGET_FW_VERSION_INVALID = "target-fw-version-invalid"
    ITEM_ERROR_CODE_TARGET_FW_VERSION_NOT_SPECIFIED = "target-fw-version-not-specified"
    ITEM_ERROR_CODE_UCS_FW_VERSION_NOT_FOUND = "ucs-fw-version-not-found"
    ITEM_STATUS_CANNOT_DETERMINE = "cannot-determine"
    ITEM_STATUS_NOT_APPLICABLE = "not-applicable"
    ITEM_STATUS_NOT_SUPPORTED = "not-supported"
    ITEM_STATUS_OK = "ok"


class HcAdapterItem(ManagedObject):
    """This is HcAdapterItem class."""

    consts = HcAdapterItemConsts()
    naming_props = set([u'itemId'])

    mo_meta = MoMeta("HcAdapterItem", "hcAdapterItem", "adapter-[item_id]", VersionMeta.Version151a, "InputOutput", 0x3fff, [], ["admin"], [u'hcServerComponent'], [u'hcItemNote', u'hcSupportedAdapterItem'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "item_error_code": MoPropertyMeta("item_error_code", "itemErrorCode", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["adapter-fw-version-not-found", "adapter-not-tagged", "dn-not-specified", "dn-not-supported", "invalid-input", "missing-data-in-catalog", "no-matching-servers-found", "none", "os-not-tagged", "retry", "target-fw-version-invalid", "target-fw-version-not-specified", "ucs-fw-version-not-found"], []), 
        "item_id": MoPropertyMeta("item_id", "itemId", "ulong", VersionMeta.Version151a, MoPropertyMeta.NAMING, 0x8, None, None, None, [], []), 
        "item_name": MoPropertyMeta("item_name", "itemName", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x10, 0, 510, None, [], []), 
        "item_note": MoPropertyMeta("item_note", "itemNote", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x20, 0, 510, None, [], []), 
        "item_ref_dn": MoPropertyMeta("item_ref_dn", "itemRefDn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x40, 0, 256, None, [], []), 
        "item_ref_id": MoPropertyMeta("item_ref_id", "itemRefId", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x80, 0, 256, None, [], []), 
        "item_ref_model": MoPropertyMeta("item_ref_model", "itemRefModel", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x100, 0, 510, None, [], []), 
        "item_status": MoPropertyMeta("item_status", "itemStatus", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["cannot-determine", "not-applicable", "not-supported", "ok"], []), 
        "item_vendor": MoPropertyMeta("item_vendor", "itemVendor", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x400, 0, 510, None, [], []), 
        "item_version": MoPropertyMeta("item_version", "itemVersion", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x800, 0, 510, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x1000, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x2000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "itemErrorCode": "item_error_code", 
        "itemId": "item_id", 
        "itemName": "item_name", 
        "itemNote": "item_note", 
        "itemRefDn": "item_ref_dn", 
        "itemRefId": "item_ref_id", 
        "itemRefModel": "item_ref_model", 
        "itemStatus": "item_status", 
        "itemVendor": "item_vendor", 
        "itemVersion": "item_version", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, item_id, **kwargs):
        self._dirty_mask = 0
        self.item_id = item_id
        self.child_action = None
        self.item_error_code = None
        self.item_name = None
        self.item_note = None
        self.item_ref_dn = None
        self.item_ref_id = None
        self.item_ref_model = None
        self.item_status = None
        self.item_vendor = None
        self.item_version = None
        self.status = None

        ManagedObject.__init__(self, "HcAdapterItem", parent_mo_or_dn, **kwargs)




"""This module contains the general information for AdaptorUsnicConnDef ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class AdaptorUsnicConnDefConsts():
    pass


class AdaptorUsnicConnDef(ManagedObject):
    """This is AdaptorUsnicConnDef class."""

    consts = AdaptorUsnicConnDefConsts()
    naming_props = set([u'conPolicyName'])

    mo_meta = MoMeta("AdaptorUsnicConnDef", "adaptorUsnicConnDef", "usnic-conn-def-[con_policy_name]", VersionMeta.Version112a, "InputOutput", 0x1f, [], ["admin", "ls-compute", "ls-config", "ls-server", "read-only"], [u'adaptorHostEthIf'], [u'adaptorEthCompQueueProfile', u'adaptorEthFailoverProfile', u'adaptorEthInterruptProfile', u'adaptorEthInterruptScalingProfile', u'adaptorEthOffloadProfile', u'adaptorEthRecvQueueProfile', u'adaptorEthWorkQueueProfile', u'adaptorExtIpV6RssHashProfile', u'adaptorIpV4RssHashProfile', u'adaptorIpV6RssHashProfile', u'adaptorRssProfile'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version112a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "con_policy_name": MoPropertyMeta("con_policy_name", "conPolicyName", "string", VersionMeta.Version112a, MoPropertyMeta.NAMING, 0x2, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "usnic_count": MoPropertyMeta("usnic_count", "usnicCount", "uint", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "conPolicyName": "con_policy_name", 
        "dn": "dn", 
        "rn": "rn", 
        "status": "status", 
        "usnicCount": "usnic_count", 
    }

    def __init__(self, parent_mo_or_dn, con_policy_name, **kwargs):
        self._dirty_mask = 0
        self.con_policy_name = con_policy_name
        self.child_action = None
        self.status = None
        self.usnic_count = None

        ManagedObject.__init__(self, "AdaptorUsnicConnDef", parent_mo_or_dn, **kwargs)




"""This module contains the general information for IdentIdentCtx ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class IdentIdentCtxConsts():
    CONS_TYPE_CHASSIS = "chassis"
    CONS_TYPE_SERVER = "server"
    CONS_TYPE_VHBA = "vhba"
    CONS_TYPE_VM = "vm"
    CONS_TYPE_VMNIC = "vmnic"
    CONS_TYPE_VNIC = "vnic"
    DEFINED_IN_IDM_NO = "no"
    DEFINED_IN_IDM_YES = "yes"
    GLOBAL_ASSIGNED_CNT_NOT_DEFINED_IN_POOL = "not-defined-in-pool"
    GLOBAL_DEFINED_CNT_NOT_DEFINED_IN_POOL = "not-defined-in-pool"
    IDENT_TYPE_IP_V4 = "ipV4"
    IDENT_TYPE_IP_V6 = "ipV6"
    IDENT_TYPE_IQN = "iqn"
    IDENT_TYPE_MAC = "mac"
    IDENT_TYPE_UUID = "uuid"
    IDENT_TYPE_VLAN = "vlan"
    IDENT_TYPE_WWNN = "wwnn"
    IDENT_TYPE_WWPN = "wwpn"
    INTENT_ADD_POOLED = "add-pooled"
    INTENT_ASSIGN = "assign"
    INTENT_CHECK_DUPLICATE_ID = "check-duplicate-id"
    INTENT_DELETE_POOLED = "delete-pooled"
    INTENT_RE_EVALUATE = "re-evaluate"
    INTENT_REQUISITION = "requisition"
    INTENT_SYNC = "sync"
    INTENT_UNASSIGN = "unassign"
    INTENT_UNASSIGN_ON_BEHALF_OF_UCSM = "unassign-on-behalf-of-ucsm"
    INTENT_VALIDATE = "validate"
    IS_FROM_GLOBAL_POOL_FALSE = "false"
    IS_FROM_GLOBAL_POOL_NO = "no"
    IS_FROM_GLOBAL_POOL_TRUE = "true"
    IS_FROM_GLOBAL_POOL_YES = "yes"
    IS_STATIC_ID_FALSE = "false"
    IS_STATIC_ID_NO = "no"
    IS_STATIC_ID_TRUE = "true"
    IS_STATIC_ID_YES = "yes"
    RET_STATUS_ASSIGNED_BY_OTHER = "assigned-by-other"
    RET_STATUS_FAILED = "failed"
    RET_STATUS_IN_TRANSIT = "in-transit"
    RET_STATUS_INVALID = "invalid"
    RET_STATUS_OUT_OF_SYNC = "out-of-sync"
    RET_STATUS_SUCCEEDED = "succeeded"
    RET_STATUS_SYNCED = "synced"
    RET_STATUS_VALID = "valid"
    USING_QUALIFIED_POOL_NO = "no"
    USING_QUALIFIED_POOL_YES = "yes"


class IdentIdentCtx(ManagedObject):
    """This is IdentIdentCtx class."""

    consts = IdentIdentCtxConsts()
    naming_props = set([u'seqNum'])

    mo_meta = MoMeta("IdentIdentCtx", "identIdentCtx", "IdCtx-[seq_num]", VersionMeta.Version101a, "InputOutput", 0x1f, [], ["read-only"], [u'identIdentRequest'], [], [None])

    prop_meta = {
        "assigned": MoPropertyMeta("assigned", "assigned", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "cons_dn": MoPropertyMeta("cons_dn", "consDn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "cons_type": MoPropertyMeta("cons_type", "consType", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["chassis", "server", "vhba", "vm", "vmnic", "vnic"], []), 
        "default_ident_pool_name": MoPropertyMeta("default_ident_pool_name", "defaultIdentPoolName", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "defined_in_idm": MoPropertyMeta("defined_in_idm", "definedInIdm", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "yes"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "domain_id": MoPropertyMeta("domain_id", "domainId", "uint", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "global_assigned_cnt": MoPropertyMeta("global_assigned_cnt", "globalAssignedCnt", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-defined-in-pool"], ["0-4294967295"]), 
        "global_defined_cnt": MoPropertyMeta("global_defined_cnt", "globalDefinedCnt", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-defined-in-pool"], ["0-4294967295"]), 
        "ident_pool_name": MoPropertyMeta("ident_pool_name", "identPoolName", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "ident_type": MoPropertyMeta("ident_type", "identType", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["ipV4", "ipV6", "iqn", "mac", "uuid", "vlan", "wwnn", "wwpn"], []), 
        "intent": MoPropertyMeta("intent", "intent", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["add-pooled", "assign", "check-duplicate-id", "delete-pooled", "re-evaluate", "requisition", "sync", "unassign", "unassign-on-behalf-of-ucsm", "validate"], []), 
        "is_from_global_pool": MoPropertyMeta("is_from_global_pool", "isFromGlobalPool", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "is_static_id": MoPropertyMeta("is_static_id", "isStaticId", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "pool_dn": MoPropertyMeta("pool_dn", "poolDn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "pool_org_dn": MoPropertyMeta("pool_org_dn", "poolOrgDn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "pooled_id": MoPropertyMeta("pooled_id", "pooledId", "uint", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "replaced_acquirer": MoPropertyMeta("replaced_acquirer", "replacedAcquirer", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "ret_status": MoPropertyMeta("ret_status", "retStatus", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["assigned-by-other", "failed", "in-transit", "invalid", "out-of-sync", "succeeded", "synced", "valid"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "seq_num": MoPropertyMeta("seq_num", "seqNum", "uint", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x8, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suppl_id1": MoPropertyMeta("suppl_id1", "supplId1", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "suppl_id2": MoPropertyMeta("suppl_id2", "supplId2", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "suppl_id3": MoPropertyMeta("suppl_id3", "supplId3", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "suppl_id4": MoPropertyMeta("suppl_id4", "supplId4", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "ucsm_id": MoPropertyMeta("ucsm_id", "ucsmId", "uint", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "using_qualified_pool": MoPropertyMeta("using_qualified_pool", "usingQualifiedPool", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "yes"], []), 
        "validate_msg": MoPropertyMeta("validate_msg", "validateMsg", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
    }

    prop_map = {
        "assigned": "assigned", 
        "childAction": "child_action", 
        "consDn": "cons_dn", 
        "consType": "cons_type", 
        "defaultIdentPoolName": "default_ident_pool_name", 
        "definedInIdm": "defined_in_idm", 
        "dn": "dn", 
        "domainId": "domain_id", 
        "globalAssignedCnt": "global_assigned_cnt", 
        "globalDefinedCnt": "global_defined_cnt", 
        "identPoolName": "ident_pool_name", 
        "identType": "ident_type", 
        "intent": "intent", 
        "isFromGlobalPool": "is_from_global_pool", 
        "isStaticId": "is_static_id", 
        "poolDn": "pool_dn", 
        "poolOrgDn": "pool_org_dn", 
        "pooledId": "pooled_id", 
        "replacedAcquirer": "replaced_acquirer", 
        "retStatus": "ret_status", 
        "rn": "rn", 
        "seqNum": "seq_num", 
        "status": "status", 
        "supplId1": "suppl_id1", 
        "supplId2": "suppl_id2", 
        "supplId3": "suppl_id3", 
        "supplId4": "suppl_id4", 
        "ucsmId": "ucsm_id", 
        "usingQualifiedPool": "using_qualified_pool", 
        "validateMsg": "validate_msg", 
    }

    def __init__(self, parent_mo_or_dn, seq_num, **kwargs):
        self._dirty_mask = 0
        self.seq_num = seq_num
        self.assigned = None
        self.child_action = None
        self.cons_dn = None
        self.cons_type = None
        self.default_ident_pool_name = None
        self.defined_in_idm = None
        self.domain_id = None
        self.global_assigned_cnt = None
        self.global_defined_cnt = None
        self.ident_pool_name = None
        self.ident_type = None
        self.intent = None
        self.is_from_global_pool = None
        self.is_static_id = None
        self.pool_dn = None
        self.pool_org_dn = None
        self.pooled_id = None
        self.replaced_acquirer = None
        self.ret_status = None
        self.status = None
        self.suppl_id1 = None
        self.suppl_id2 = None
        self.suppl_id3 = None
        self.suppl_id4 = None
        self.ucsm_id = None
        self.using_qualified_pool = None
        self.validate_msg = None

        ManagedObject.__init__(self, "IdentIdentCtx", parent_mo_or_dn, **kwargs)




"""This module contains the general information for TrigAbsWindow ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class TrigAbsWindowConsts():
    CONCUR_CAP_UNLIMITED = "unlimited"
    PROC_BREAK_NONE = "none"
    PROC_CAP_UNLIMITED = "unlimited"
    TIME_CAP_NONE = "none"


class TrigAbsWindow(ManagedObject):
    """This is TrigAbsWindow class."""

    consts = TrigAbsWindowConsts()
    naming_props = set([u'name'])

    mo_meta = MoMeta("TrigAbsWindow", "trigAbsWindow", "abs-[name]", VersionMeta.Version101a, "InputOutput", 0x3ff, [], ["admin", "ls-compute", "ls-config", "ls-server", "operations"], [u'trigSched'], [], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "concur_cap": MoPropertyMeta("concur_cap", "concurCap", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["unlimited"], ["0-65535"]), 
        "date": MoPropertyMeta("date", "date", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "job_count": MoPropertyMeta("job_count", "jobCount", "uint", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []), 
        "proc_break": MoPropertyMeta("proc_break", "procBreak", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""[0-9]+:([0-1][0-9]|2[0-3]):[0-5][0-9]:[0-5][0-9](\.[0-9]{1,3})?""", ["none"], ["0-4294967295"]), 
        "proc_cap": MoPropertyMeta("proc_cap", "procCap", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["unlimited"], ["0-65535"]), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "time_cap": MoPropertyMeta("time_cap", "timeCap", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""[0-9]+:([0-1][0-9]|2[0-3]):[0-5][0-9]:[0-5][0-9](\.[0-9]{1,3})?""", ["none"], ["0-4294967295"]), 
    }

    prop_map = {
        "childAction": "child_action", 
        "concurCap": "concur_cap", 
        "date": "date", 
        "dn": "dn", 
        "jobCount": "job_count", 
        "name": "name", 
        "procBreak": "proc_break", 
        "procCap": "proc_cap", 
        "rn": "rn", 
        "status": "status", 
        "timeCap": "time_cap", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.concur_cap = None
        self.date = None
        self.job_count = None
        self.proc_break = None
        self.proc_cap = None
        self.status = None
        self.time_cap = None

        ManagedObject.__init__(self, "TrigAbsWindow", parent_mo_or_dn, **kwargs)




"""This module contains the general information for StorageFlexFlashController ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class StorageFlexFlashControllerConsts():
    ADMIN_SLOT_NUMBER_1 = "1"
    ADMIN_SLOT_NUMBER_2 = "2"
    ADMIN_SLOT_NUMBER_NA = "NA"
    CONFIGURED_MODE_INDEPENDENT_DRIVES = "independent-drives"
    CONFIGURED_MODE_MIRROR = "mirror"
    CONFIGURED_MODE_UNKNOWN = "unknown"
    CONTROLLER_HEALTH_FFCH_ERROR_CARDS_ACCESS_ERROR = "FFCH_ERROR_CARDS_ACCESS_ERROR"
    CONTROLLER_HEALTH_FFCH_ERROR_CARD_SIZE_MISMATCH = "FFCH_ERROR_CARD_SIZE_MISMATCH"
    CONTROLLER_HEALTH_FFCH_ERROR_INCONSISTANT_METADATA_IGNORED = "FFCH_ERROR_INCONSISTANT_METADATA_IGNORED"
    CONTROLLER_HEALTH_FFCH_ERROR_INVALID_SIZE = "FFCH_ERROR_INVALID_SIZE"
    CONTROLLER_HEALTH_FFCH_ERROR_MEDIA_WRITE_PROTECTED = "FFCH_ERROR_MEDIA_WRITE_PROTECTED"
    CONTROLLER_HEALTH_FFCH_ERROR_OLD_FIRMWARE_RUNNING = "FFCH_ERROR_OLD_FIRMWARE_RUNNING"
    CONTROLLER_HEALTH_FFCH_ERROR_REBOOTED_DURING_REBUILD = "FFCH_ERROR_REBOOTED_DURING_REBUILD"
    CONTROLLER_HEALTH_FFCH_ERROR_SD247_CARD_DETECTED = "FFCH_ERROR_SD247_CARD_DETECTED"
    CONTROLLER_HEALTH_FFCH_ERROR_SD253_WITH_UN_OR_SD247 = "FFCH_ERROR_SD253_WITH_UN_OR_SD247"
    CONTROLLER_HEALTH_FFCH_ERROR_SD_CARD_NOT_CONFIGURED = "FFCH_ERROR_SD_CARD_NOT_CONFIGURED"
    CONTROLLER_HEALTH_FFCH_ERROR_SECONDARY_UNHEALTHY_CARD = "FFCH_ERROR_SECONDARY_UNHEALTHY_CARD"
    CONTROLLER_HEALTH_FFCH_FLEXD_ERROR_IM_SD0_IGNORED_SD1 = "FFCH_FLEXD_ERROR_IM_SD0_IGNORED_SD1"
    CONTROLLER_HEALTH_FFCH_FLEXD_ERROR_IM_SD0_SD1_IGNORED = "FFCH_FLEXD_ERROR_IM_SD0_SD1_IGNORED"
    CONTROLLER_HEALTH_FFCH_FLEXD_ERROR_IM_SD_CARDS_OP_MODE_MISMATCH = "FFCH_FLEXD_ERROR_IM_SD_CARDS_OP_MODE_MISMATCH"
    CONTROLLER_HEALTH_FFCH_FLEXD_ERROR_IM_SD_HEALTHY_SD_UN_IGNORED = "FFCH_FLEXD_ERROR_IM_SD_HEALTHY_SD_UN_IGNORED"
    CONTROLLER_HEALTH_FFCH_FLEXD_ERROR_IM_SD_UNHEALTHY_SD_UN_IGNORED = "FFCH_FLEXD_ERROR_IM_SD_UNHEALTHY_SD_UN_IGNORED"
    CONTROLLER_HEALTH_FFCH_FLEXD_ERROR_SD_CARD0_HEALTHY_OP_MODE_MISMATCH = "FFCH_FLEXD_ERROR_SD_CARD0_HEALTHY_OP_MODE_MISMATCH"
    CONTROLLER_HEALTH_FFCH_FLEXD_ERROR_SD_CARD0_UNHEALTHY_OP_MODE_MISMATCH = "FFCH_FLEXD_ERROR_SD_CARD0_UNHEALTHY_OP_MODE_MISMATCH"
    CONTROLLER_HEALTH_FFCH_FLEXD_ERROR_SD_CARD1_HEALTHY_OP_MODE_MISMATCH = "FFCH_FLEXD_ERROR_SD_CARD1_HEALTHY_OP_MODE_MISMATCH"
    CONTROLLER_HEALTH_FFCH_FLEXD_ERROR_SD_CARD1_UNHEALTHY_OP_MODE_MISMATCH = "FFCH_FLEXD_ERROR_SD_CARD1_UNHEALTHY_OP_MODE_MISMATCH"
    CONTROLLER_HEALTH_FFCH_FLEXD_ERROR_SD_CARD_OP_MODE_MISMATCH = "FFCH_FLEXD_ERROR_SD_CARD_OP_MODE_MISMATCH"
    CONTROLLER_HEALTH_FFCH_FLEXD_ERROR_SD_OP_MODE_MISMATCH_WITH_UN = "FFCH_FLEXD_ERROR_SD_OP_MODE_MISMATCH_WITH_UN"
    CONTROLLER_HEALTH_FFCH_INCONSISTENT_METADATA = "FFCH_INCONSISTENT_METADATA"
    CONTROLLER_HEALTH_FFCH_METADATA_FAILURE = "FFCH_METADATA_FAILURE"
    CONTROLLER_HEALTH_FFCH_OK = "FFCH_OK"
    CONTROLLER_STATE_FFC_CONFIG = "FFC_CONFIG"
    CONTROLLER_STATE_FFC_FAILED = "FFC_FAILED"
    CONTROLLER_STATE_FFC_INIT = "FFC_INIT"
    CONTROLLER_STATE_FFC_REBUILDING = "FFC_REBUILDING"
    CONTROLLER_STATE_FFC_SOFTWARE_ERR = "FFC_SOFTWARE_ERR"
    CONTROLLER_STATE_FFC_UNINITALIZED = "FFC_UNINITALIZED"
    CONTROLLER_STATE_FFC_USB_CONNECTED = "FFC_USB_CONNECTED"
    CONTROLLER_STATE_FFC_USB_CONNECTING = "FFC_USB_CONNECTING"
    CONTROLLER_STATE_FFC_USB_DISCONNECTED = "FFC_USB_DISCONNECTED"
    CONTROLLER_STATE_FFC_USB_DISCONNECTING = "FFC_USB_DISCONNECTING"
    CONTROLLER_STATE_FFC_WAIT_USER = "FFC_WAIT_USER"
    FLEX_FLASH_TYPE_ASTORIA = "Astoria"
    FLEX_FLASH_TYPE_FX3_S = "FX3S"
    FLEX_FLASH_TYPE_UNKNOWN = "Unknown"
    HAS_ERROR_ERROR = "error"
    HAS_ERROR_NO_ERROR = "no_error"
    IS_CARD_MISMATCH_MATCH = "MATCH"
    IS_CARD_MISMATCH_MISMATCH = "MISMATCH"
    IS_CARD_MISMATCH_NA = "NA"
    IS_FORMAT_FSMRUNNING_NA = "NA"
    IS_FORMAT_FSMRUNNING_NO = "NO"
    IS_FORMAT_FSMRUNNING_YES = "YES"
    OPER_STATE_ACCESSIBILITY_PROBLEM = "accessibility-problem"
    OPER_STATE_AUTO_UPGRADE = "auto-upgrade"
    OPER_STATE_BACKPLANE_PORT_PROBLEM = "backplane-port-problem"
    OPER_STATE_BIOS_POST_TIMEOUT = "bios-post-timeout"
    OPER_STATE_CHASSIS_LIMIT_EXCEEDED = "chassis-limit-exceeded"
    OPER_STATE_CONFIG = "config"
    OPER_STATE_DECOMISSIONING = "decomissioning"
    OPER_STATE_DEGRADED = "degraded"
    OPER_STATE_DISABLED = "disabled"
    OPER_STATE_DISCOVERY = "discovery"
    OPER_STATE_DISCOVERY_FAILED = "discovery-failed"
    OPER_STATE_EQUIPMENT_PROBLEM = "equipment-problem"
    OPER_STATE_FABRIC_CONN_PROBLEM = "fabric-conn-problem"
    OPER_STATE_FABRIC_UNSUPPORTED_CONN = "fabric-unsupported-conn"
    OPER_STATE_IDENTIFY = "identify"
    OPER_STATE_IDENTITY_UNESTABLISHABLE = "identity-unestablishable"
    OPER_STATE_INOPERABLE = "inoperable"
    OPER_STATE_MALFORMED_FRU = "malformed-fru"
    OPER_STATE_NOT_SUPPORTED = "not-supported"
    OPER_STATE_OPERABLE = "operable"
    OPER_STATE_PEER_COMM_PROBLEM = "peer-comm-problem"
    OPER_STATE_PERFORMANCE_PROBLEM = "performance-problem"
    OPER_STATE_POST_FAILURE = "post-failure"
    OPER_STATE_POWER_PROBLEM = "power-problem"
    OPER_STATE_POWERED_OFF = "powered-off"
    OPER_STATE_REMOVED = "removed"
    OPER_STATE_THERMAL_PROBLEM = "thermal-problem"
    OPER_STATE_UNKNOWN = "unknown"
    OPER_STATE_UPGRADE_PROBLEM = "upgrade-problem"
    OPER_STATE_VOLTAGE_PROBLEM = "voltage-problem"
    OPERABILITY_ACCESSIBILITY_PROBLEM = "accessibility-problem"
    OPERABILITY_AUTO_UPGRADE = "auto-upgrade"
    OPERABILITY_BACKPLANE_PORT_PROBLEM = "backplane-port-problem"
    OPERABILITY_BIOS_POST_TIMEOUT = "bios-post-timeout"
    OPERABILITY_CHASSIS_LIMIT_EXCEEDED = "chassis-limit-exceeded"
    OPERABILITY_CONFIG = "config"
    OPERABILITY_DECOMISSIONING = "decomissioning"
    OPERABILITY_DEGRADED = "degraded"
    OPERABILITY_DISABLED = "disabled"
    OPERABILITY_DISCOVERY = "discovery"
    OPERABILITY_DISCOVERY_FAILED = "discovery-failed"
    OPERABILITY_EQUIPMENT_PROBLEM = "equipment-problem"
    OPERABILITY_FABRIC_CONN_PROBLEM = "fabric-conn-problem"
    OPERABILITY_FABRIC_UNSUPPORTED_CONN = "fabric-unsupported-conn"
    OPERABILITY_IDENTIFY = "identify"
    OPERABILITY_IDENTITY_UNESTABLISHABLE = "identity-unestablishable"
    OPERABILITY_INOPERABLE = "inoperable"
    OPERABILITY_MALFORMED_FRU = "malformed-fru"
    OPERABILITY_NOT_SUPPORTED = "not-supported"
    OPERABILITY_OPERABLE = "operable"
    OPERABILITY_PEER_COMM_PROBLEM = "peer-comm-problem"
    OPERABILITY_PERFORMANCE_PROBLEM = "performance-problem"
    OPERABILITY_POST_FAILURE = "post-failure"
    OPERABILITY_POWER_PROBLEM = "power-problem"
    OPERABILITY_POWERED_OFF = "powered-off"
    OPERABILITY_REMOVED = "removed"
    OPERABILITY_THERMAL_PROBLEM = "thermal-problem"
    OPERABILITY_UNKNOWN = "unknown"
    OPERABILITY_UPGRADE_PROBLEM = "upgrade-problem"
    OPERABILITY_VOLTAGE_PROBLEM = "voltage-problem"
    OPERATING_MODE_INDEPENDENT_DRIVES = "independent-drives"
    OPERATING_MODE_MIRROR = "mirror"
    OPERATING_MODE_UNKNOWN = "unknown"
    OPERATION_REQUEST_FORMAT = "format"
    OPERATION_REQUEST_PAIR = "pair"
    OPERATION_REQUEST_RESET = "reset"
    OPERATION_REQUEST_UNKNOWN = "unknown"
    OPERATION_REQUEST_UNPAIR = "unpair"
    PERF_LOWER_CRITICAL = "lower-critical"
    PERF_LOWER_NON_CRITICAL = "lower-non-critical"
    PERF_LOWER_NON_RECOVERABLE = "lower-non-recoverable"
    PERF_NOT_SUPPORTED = "not-supported"
    PERF_OK = "ok"
    PERF_UNKNOWN = "unknown"
    PERF_UPPER_CRITICAL = "upper-critical"
    PERF_UPPER_NON_CRITICAL = "upper-non-critical"
    PERF_UPPER_NON_RECOVERABLE = "upper-non-recoverable"
    POWER_DEGRADED = "degraded"
    POWER_ERROR = "error"
    POWER_FAILED = "failed"
    POWER_NOT_SUPPORTED = "not-supported"
    POWER_OFF = "off"
    POWER_OFFDUTY = "offduty"
    POWER_OFFLINE = "offline"
    POWER_OK = "ok"
    POWER_ON = "on"
    POWER_ONLINE = "online"
    POWER_POWER_SAVE = "power-save"
    POWER_TEST = "test"
    POWER_UNKNOWN = "unknown"
    PRESENCE_EMPTY = "empty"
    PRESENCE_EQUIPPED = "equipped"
    PRESENCE_EQUIPPED_IDENTITY_UNESTABLISHABLE = "equipped-identity-unestablishable"
    PRESENCE_EQUIPPED_NOT_PRIMARY = "equipped-not-primary"
    PRESENCE_EQUIPPED_SLAVE = "equipped-slave"
    PRESENCE_EQUIPPED_UNSUPPORTED = "equipped-unsupported"
    PRESENCE_EQUIPPED_WITH_MALFORMED_FRU = "equipped-with-malformed-fru"
    PRESENCE_INACCESSIBLE = "inaccessible"
    PRESENCE_MISMATCH = "mismatch"
    PRESENCE_MISMATCH_IDENTITY_UNESTABLISHABLE = "mismatch-identity-unestablishable"
    PRESENCE_MISMATCH_SLAVE = "mismatch-slave"
    PRESENCE_MISSING = "missing"
    PRESENCE_MISSING_SLAVE = "missing-slave"
    PRESENCE_NOT_SUPPORTED = "not-supported"
    PRESENCE_UNAUTHORIZED = "unauthorized"
    PRESENCE_UNKNOWN = "unknown"
    RAID_SYNC_SUPPORT_NO = "no"
    RAID_SYNC_SUPPORT_YES = "yes"
    THERMAL_LOWER_CRITICAL = "lower-critical"
    THERMAL_LOWER_NON_CRITICAL = "lower-non-critical"
    THERMAL_LOWER_NON_RECOVERABLE = "lower-non-recoverable"
    THERMAL_NOT_SUPPORTED = "not-supported"
    THERMAL_OK = "ok"
    THERMAL_UNKNOWN = "unknown"
    THERMAL_UPPER_CRITICAL = "upper-critical"
    THERMAL_UPPER_NON_CRITICAL = "upper-non-critical"
    THERMAL_UPPER_NON_RECOVERABLE = "upper-non-recoverable"
    TYPE_FLASH = "FLASH"
    TYPE_HBA = "HBA"
    TYPE_NVME = "NVME"
    TYPE_PCH = "PCH"
    TYPE_PT = "PT"
    TYPE_SAS = "SAS"
    TYPE_SATA = "SATA"
    TYPE_SD = "SD"
    TYPE_EXTERNAL = "external"
    TYPE_UNKNOWN = "unknown"
    VOLTAGE_LOWER_CRITICAL = "lower-critical"
    VOLTAGE_LOWER_NON_CRITICAL = "lower-non-critical"
    VOLTAGE_LOWER_NON_RECOVERABLE = "lower-non-recoverable"
    VOLTAGE_NOT_SUPPORTED = "not-supported"
    VOLTAGE_OK = "ok"
    VOLTAGE_UNKNOWN = "unknown"
    VOLTAGE_UPPER_CRITICAL = "upper-critical"
    VOLTAGE_UPPER_NON_CRITICAL = "upper-non-critical"
    VOLTAGE_UPPER_NON_RECOVERABLE = "upper-non-recoverable"


class StorageFlexFlashController(ManagedObject):
    """This is StorageFlexFlashController class."""

    consts = StorageFlexFlashControllerConsts()
    naming_props = set([u'id'])

    mo_meta = MoMeta("StorageFlexFlashController", "storageFlexFlashController", "storage-flexflash-[id]", VersionMeta.Version112a, "InputOutput", 0x7f, [], ["admin"], [u'computeBoard'], [u'firmwareRunning', u'storageFlexFlashCard', u'storageFlexFlashControllerOperation', u'storageFlexFlashVirtualDrive', u'storageLocalDiskConfigDef'], ["Get"])

    prop_meta = {
        "admin_slot_number": MoPropertyMeta("admin_slot_number", "adminSlotNumber", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["1", "2", "NA"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version112a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "configured_mode": MoPropertyMeta("configured_mode", "configuredMode", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["independent-drives", "mirror", "unknown"], []), 
        "controller_health": MoPropertyMeta("controller_health", "controllerHealth", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["FFCH_ERROR_CARDS_ACCESS_ERROR", "FFCH_ERROR_CARD_SIZE_MISMATCH", "FFCH_ERROR_INCONSISTANT_METADATA_IGNORED", "FFCH_ERROR_INVALID_SIZE", "FFCH_ERROR_MEDIA_WRITE_PROTECTED", "FFCH_ERROR_OLD_FIRMWARE_RUNNING", "FFCH_ERROR_REBOOTED_DURING_REBUILD", "FFCH_ERROR_SD247_CARD_DETECTED", "FFCH_ERROR_SD253_WITH_UN_OR_SD247", "FFCH_ERROR_SD_CARD_NOT_CONFIGURED", "FFCH_ERROR_SECONDARY_UNHEALTHY_CARD", "FFCH_FLEXD_ERROR_IM_SD0_IGNORED_SD1", "FFCH_FLEXD_ERROR_IM_SD0_SD1_IGNORED", "FFCH_FLEXD_ERROR_IM_SD_CARDS_OP_MODE_MISMATCH", "FFCH_FLEXD_ERROR_IM_SD_HEALTHY_SD_UN_IGNORED", "FFCH_FLEXD_ERROR_IM_SD_UNHEALTHY_SD_UN_IGNORED", "FFCH_FLEXD_ERROR_SD_CARD0_HEALTHY_OP_MODE_MISMATCH", "FFCH_FLEXD_ERROR_SD_CARD0_UNHEALTHY_OP_MODE_MISMATCH", "FFCH_FLEXD_ERROR_SD_CARD1_HEALTHY_OP_MODE_MISMATCH", "FFCH_FLEXD_ERROR_SD_CARD1_UNHEALTHY_OP_MODE_MISMATCH", "FFCH_FLEXD_ERROR_SD_CARD_OP_MODE_MISMATCH", "FFCH_FLEXD_ERROR_SD_OP_MODE_MISMATCH_WITH_UN", "FFCH_INCONSISTENT_METADATA", "FFCH_METADATA_FAILURE", "FFCH_OK"], []), 
        "controller_state": MoPropertyMeta("controller_state", "controllerState", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["FFC_CONFIG", "FFC_FAILED", "FFC_INIT", "FFC_REBUILDING", "FFC_SOFTWARE_ERR", "FFC_UNINITALIZED", "FFC_USB_CONNECTED", "FFC_USB_CONNECTING", "FFC_USB_DISCONNECTED", "FFC_USB_DISCONNECTING", "FFC_WAIT_USER"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "firmware_version": MoPropertyMeta("firmware_version", "firmwareVersion", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "flex_flash_type": MoPropertyMeta("flex_flash_type", "flexFlashType", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["Astoria", "FX3S", "Unknown"], []), 
        "has_error": MoPropertyMeta("has_error", "hasError", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["error", "no_error"], []), 
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version112a, MoPropertyMeta.NAMING, 0x8, None, None, None, [], ["1-64"]), 
        "is_card_mismatch": MoPropertyMeta("is_card_mismatch", "isCardMismatch", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["MATCH", "MISMATCH", "NA"], []), 
        "is_format_fsm_running": MoPropertyMeta("is_format_fsm_running", "isFormatFSMRunning", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA", "NO", "YES"], []), 
        "location_dn": MoPropertyMeta("location_dn", "locationDn", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "oper_qualifier_reason": MoPropertyMeta("oper_qualifier_reason", "operQualifierReason", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["accessibility-problem", "auto-upgrade", "backplane-port-problem", "bios-post-timeout", "chassis-limit-exceeded", "config", "decomissioning", "degraded", "disabled", "discovery", "discovery-failed", "equipment-problem", "fabric-conn-problem", "fabric-unsupported-conn", "identify", "identity-unestablishable", "inoperable", "malformed-fru", "not-supported", "operable", "peer-comm-problem", "performance-problem", "post-failure", "power-problem", "powered-off", "removed", "thermal-problem", "unknown", "upgrade-problem", "voltage-problem"], []), 
        "operability": MoPropertyMeta("operability", "operability", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["accessibility-problem", "auto-upgrade", "backplane-port-problem", "bios-post-timeout", "chassis-limit-exceeded", "config", "decomissioning", "degraded", "disabled", "discovery", "discovery-failed", "equipment-problem", "fabric-conn-problem", "fabric-unsupported-conn", "identify", "identity-unestablishable", "inoperable", "malformed-fru", "not-supported", "operable", "peer-comm-problem", "performance-problem", "post-failure", "power-problem", "powered-off", "removed", "thermal-problem", "unknown", "upgrade-problem", "voltage-problem"], []), 
        "operating_mode": MoPropertyMeta("operating_mode", "operatingMode", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["independent-drives", "mirror", "unknown"], []), 
        "operation_request": MoPropertyMeta("operation_request", "operationRequest", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["format", "pair", "reset", "unknown", "unpair"], []), 
        "pci_addr": MoPropertyMeta("pci_addr", "pciAddr", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "pci_slot": MoPropertyMeta("pci_slot", "pciSlot", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "perf": MoPropertyMeta("perf", "perf", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lower-critical", "lower-non-critical", "lower-non-recoverable", "not-supported", "ok", "unknown", "upper-critical", "upper-non-critical", "upper-non-recoverable"], []), 
        "physical_drive_count": MoPropertyMeta("physical_drive_count", "physicalDriveCount", "ushort", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "power": MoPropertyMeta("power", "power", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["degraded", "error", "failed", "not-supported", "off", "offduty", "offline", "ok", "on", "online", "power-save", "test", "unknown"], []), 
        "presence": MoPropertyMeta("presence", "presence", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["empty", "equipped", "equipped-identity-unestablishable", "equipped-not-primary", "equipped-slave", "equipped-unsupported", "equipped-with-malformed-fru", "inaccessible", "mismatch", "mismatch-identity-unestablishable", "mismatch-slave", "missing", "missing-slave", "not-supported", "unauthorized", "unknown"], []), 
        "primary_slot_number": MoPropertyMeta("primary_slot_number", "primarySlotNumber", "ushort", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "raid_sync_support": MoPropertyMeta("raid_sync_support", "raidSyncSupport", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "yes"], []), 
        "read_error_threshold": MoPropertyMeta("read_error_threshold", "readErrorThreshold", "uint", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "revision": MoPropertyMeta("revision", "revision", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []), 
        "serial": MoPropertyMeta("serial", "serial", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "thermal": MoPropertyMeta("thermal", "thermal", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lower-critical", "lower-non-critical", "lower-non-recoverable", "not-supported", "ok", "unknown", "upper-critical", "upper-non-critical", "upper-non-recoverable"], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["FLASH", "HBA", "NVME", "PCH", "PT", "SAS", "SATA", "SD", "external", "unknown"], []), 
        "vendor": MoPropertyMeta("vendor", "vendor", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "virtual_drive_count": MoPropertyMeta("virtual_drive_count", "virtualDriveCount", "ushort", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "voltage": MoPropertyMeta("voltage", "voltage", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lower-critical", "lower-non-critical", "lower-non-recoverable", "not-supported", "ok", "unknown", "upper-critical", "upper-non-critical", "upper-non-recoverable"], []), 
        "write_error_threshold": MoPropertyMeta("write_error_threshold", "writeErrorThreshold", "uint", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
    }

    prop_map = {
        "adminSlotNumber": "admin_slot_number", 
        "childAction": "child_action", 
        "configuredMode": "configured_mode", 
        "controllerHealth": "controller_health", 
        "controllerState": "controller_state", 
        "dn": "dn", 
        "firmwareVersion": "firmware_version", 
        "flexFlashType": "flex_flash_type", 
        "hasError": "has_error", 
        "id": "id", 
        "isCardMismatch": "is_card_mismatch", 
        "isFormatFSMRunning": "is_format_fsm_running", 
        "locationDn": "location_dn", 
        "model": "model", 
        "operQualifierReason": "oper_qualifier_reason", 
        "operState": "oper_state", 
        "operability": "operability", 
        "operatingMode": "operating_mode", 
        "operationRequest": "operation_request", 
        "pciAddr": "pci_addr", 
        "pciSlot": "pci_slot", 
        "perf": "perf", 
        "physicalDriveCount": "physical_drive_count", 
        "power": "power", 
        "presence": "presence", 
        "primarySlotNumber": "primary_slot_number", 
        "raidSyncSupport": "raid_sync_support", 
        "readErrorThreshold": "read_error_threshold", 
        "revision": "revision", 
        "rn": "rn", 
        "serial": "serial", 
        "status": "status", 
        "thermal": "thermal", 
        "type": "type", 
        "vendor": "vendor", 
        "virtualDriveCount": "virtual_drive_count", 
        "voltage": "voltage", 
        "writeErrorThreshold": "write_error_threshold", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.admin_slot_number = None
        self.child_action = None
        self.configured_mode = None
        self.controller_health = None
        self.controller_state = None
        self.firmware_version = None
        self.flex_flash_type = None
        self.has_error = None
        self.is_card_mismatch = None
        self.is_format_fsm_running = None
        self.location_dn = None
        self.model = None
        self.oper_qualifier_reason = None
        self.oper_state = None
        self.operability = None
        self.operating_mode = None
        self.operation_request = None
        self.pci_addr = None
        self.pci_slot = None
        self.perf = None
        self.physical_drive_count = None
        self.power = None
        self.presence = None
        self.primary_slot_number = None
        self.raid_sync_support = None
        self.read_error_threshold = None
        self.revision = None
        self.serial = None
        self.status = None
        self.thermal = None
        self.type = None
        self.vendor = None
        self.virtual_drive_count = None
        self.voltage = None
        self.write_error_threshold = None

        ManagedObject.__init__(self, "StorageFlexFlashController", parent_mo_or_dn, **kwargs)




# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import logging
import datetime
from ..ucscexception import UcscValidationException, \
    UcscOperationError

log = logging.getLogger('ucscentral')


def domain_register(handle, domain_name_or_ip,
                    username, password,
                    timeout=2 * 60):
    """
    This method registers Ucs domain to Ucs Central.

    Args:
        handle (UcscHandle): UcsCentral Connection handle
        domain_name_or_ip (str): Domain name or IP
        username(str): User name of the domain
        password(str): Password of the domain

    Returns:
        PolicyControlEpOp object

    Example:
        domain_register(handle, domain_name_or_ip="192.168.1.1",
                        username="admin",password="password")
    """

    from distutils.version import LooseVersion as VERSION
    from ucscsdk.mometa.policy.PolicyControlEpOp import\
        PolicyControlEpOp, PolicyControlEpOpConsts

    if VERSION(handle.get_firmware_version()) < VERSION("1.5"):
        raise UcscOperationError(
                "Domain register",
                "Operation only supported from version 1.5 onwards")

    if is_domain_registered(handle, domain_name_or_ip):
        domain_dn = "holder/domain-ep/control-ep-" + domain_name_or_ip
        domain_register = handle.query_dn(domain_dn)
        log.debug("Domain already registered with Ucs Central")
        return domain_register

    parent_dn = "holder/domain-ep"

    domain_register = PolicyControlEpOp(parent_mo_or_dn=parent_dn,
                                        host_name_or_ip=domain_name_or_ip,
                                        name=username,
                                        password=password)
    domain_register.action_event = \
        PolicyControlEpOpConsts.ACTION_EVENT_REGISTER
    handle.add_mo(domain_register)
    handle.commit()

    start = datetime.datetime.now()
    while not domain_register.registration_state == \
            PolicyControlEpOpConsts.REGISTRATION_STATE_REGISTERED:
        domain_register = handle.query_dn(domain_register.dn)
        if domain_register.registration_state == \
                PolicyControlEpOpConsts.REGISTRATION_STATE_FAILED:
            raise UcscOperationError(
                    "Registration of '%s'" %
                    domain_name_or_ip, "%s" %
                    domain_register.fsm_rmt_inv_err_descr)
        if (datetime.datetime.now() - start).total_seconds() > timeout:
            raise UcscOperationError(
                    "Registration of '%s' " %
                    domain_name_or_ip, "timeout error %s" %
                    domain_register.fsm_rmt_inv_err_descr)

    log.debug("Domain got successfully registered with Ucs Central")
    return domain_register


def is_domain_registered(handle, domain_name_or_ip):
    """
    This method returns Boolean value depending on whether given domain is
    registered with UcsCentral

    Args:
        handle (UcscHandle): UcsCentral Connection handle
        domain_name_or_ip (str): Domain name or IP

    Returns:
        True/False

    Example:
        is_domain_registered(handle, domain_name_or_ip="192.168.1.1")
    """

    from ucscsdk.mometa.policy.PolicyControlEpOp import\
        PolicyControlEpOpConsts

    domain_dn = "holder/domain-ep/control-ep-" + domain_name_or_ip
    domain_register = handle.query_dn(domain_dn)

    if domain_register:
        if domain_register.registration_state == \
                PolicyControlEpOpConsts.REGISTRATION_STATE_REGISTERED:
            return True
        else:
            log.debug("Domain registration is in-progress or has failed")
            return False
    else:
        log.debug("Domain is not registered with UcsCentral")
        return False


def domain_unregister(handle, domain_name_or_ip):
    """
    This method unregisters Ucs domain from Ucs Central.

    Args:
        handle (UcscHandle): UcsCentral Connection handle
        domain_name_or_ip (str): Domain name or IP

    Returns:
        None

    Example:
        domain_unregister(handle, domain_name_or_ip="192.168.1.1")
    """

    from distutils.version import LooseVersion as VERSION
    from ucscsdk.mometa.policy.PolicyControlEpOp import\
        PolicyControlEpOpConsts

    if VERSION(handle.get_firmware_version()) < VERSION("1.5"):
        raise UcscOperationError(
                "Domain unregister",
                "Operation only supported from version 1.5 onwards")

    filter_str = '(host_name_or_ip, %s, type="eq")' % domain_name_or_ip

    domains_registered = handle.query_classid(class_id="PolicyControlEpOp",
                                              filter_str=filter_str)
    if (len(domains_registered) <= 0):
        raise UcscOperationError(
            "Domain unregister",
            "Domain with name or IP %s not registered with UcsCentral"
            % domain_name_or_ip)

    domain_register = domains_registered[0]

    if not _is_domain_available(handle, domain_register.sys_id):
        raise UcscOperationError(
            "Domain unregister",
            "Not able to connect with Domain %s" % domain_name_or_ip)

    domain_register.action_event = \
        PolicyControlEpOpConsts.ACTION_EVENT_UNREGISTER
    handle.set_mo(domain_register)
    handle.commit()

    log.debug("Domain was successfully unregistered from Ucs Central")


def get_domain(handle, domain_ip, domain_name=None):
    """
    This method gets the computeSystem object for the Ucs domain.

    Args:
        handle (UcscHandle): UcsCentral Connection handle
        domain_ip(str): IP of domain, set 'None' if domain_name is valid
        domain_name(str): Optional Domain name, valid only if domain_ip is None

    Returns:
        domain object

    Example:
        get_domain(handle, domain_ip="192.168.1.1", domain_name=" ")
        get_domain(handle, domain_ip=None, domain_name="test-dom")
    """

    if domain_ip:
        filter_str = '(address, %s, type="eq")' % domain_ip
    else:
        filter_str = '(name, %s, type="eq")' % domain_name

    domain = handle.query_classid(
        class_id='ComputeSystem', filter_str=filter_str)

    if (len(domain) <= 0):
        raise UcscOperationError("Get domain",
                                 "Domain with IP %s or name %s "
                                 "does not exist" %
                                 (domain_ip, domain_name))

    return domain[0]


def get_domain_operational_status(handle, domain_ip, domain_name=None):
    """
    This method gets the operational status of the Ucs domain wrt UcsCentral.

    Args:
        handle (UcscHandle): UcsCentral Connection handle
        domain_ip(str): IP of domain, set 'None' if domain_name is valid
        domain_name(str): Optional Domain name, valid only if domain_ip is None

    Returns:
        Operational status of domain

    Example:
        get_domain_operational_status(handle, domain_ip="192.168.1.1")
    """

    domain = get_domain(handle, domain_ip, domain_name)

    if not domain:
        raise UcscOperationError("Get domain operational status",
                                 "Domain with IP %s or name %s "
                                 "does not exist" %
                                 (domain_ip, domain_name))

    extpol_client_dn = "extpol/reg/clients/client-" + domain.id
    extpol_client = handle.query_dn(extpol_client_dn)

    if not extpol_client:
        raise UcscOperationError("Get domain operational status",
                                 "Domain with IP %s or name %s "
                                 "does not exist" %
                                 (domain_ip, domain_name))
    return extpol_client.oper_state


def _is_domain_available(handle, domain_id):
    """
    This internal method returns True if domain is available currently
    else returns False

    Args:
        handle (UcscHandle): UcsCentral Connection handle
        domain_id(str): ID of domain from domain object

    Returns:
        True or False depending on domain's availability

    Example:
        _is_domain_available(handle, domain_id="1008")
    """

    extpol_client_dn = "extpol/reg/clients/client-" + domain_id
    extpol_client = handle.query_dn(extpol_client_dn)

    if (extpol_client and (extpol_client.oper_state == "registered")):
        return True

    return False


def domain_group_create(handle, name,
                        descr="",
                        parent_dn="domaingroup-root"):
    """
    This method creates Domain Group.

    Args:
        handle (UcscHandle): UcsCentral Connection handle
        name (str): Name of the domain group.
        descr (str): Basic description.
        parent_dn (str): Parent org for the domain group

    Returns:
        None

    Example:
        domain_group_create(handle, name="sample_dom_grp")
    """

    from ucscsdk.mometa.org.OrgDomainGroup import\
        OrgDomainGroup

    org = handle.query_dn(parent_dn)
    if not org:
        raise UcscOperationError(
            "Domain group create",
            "org '%s' does not exist" % parent_dn)

    mo = OrgDomainGroup(parent_mo_or_dn=org.dn,
                        name=name,
                        descr=descr)
    handle.add_mo(mo)
    handle.commit()


def get_domain_group_dn(handle, domain_group):
    """
    This utility funciton gets domain_group dn given the domain group name.

    Args:
        handle (UcscHandle): UcsCentral Connection handle
        domain_ip(str): IP of domain, set 'None' if domain_name is valid
        domain_group(string): Full domain_group with root/<org_name>/..
        domain_name(str): Optional Domain name, valid only if domain_ip is None

    Returns:
        domain_group dn, raises Exception if domain group doesn't exist

    Example:
        get_domain_group_dn(handle, domain_group="root/sampleDomGroup")
    """

    domain_org = []
    domain_group_dn_prefix = "domaingroup-"
    orgs = domain_group.split("/")
    for org in orgs:
        domain_org.append(domain_group_dn_prefix + org)

    domain_group_dn = ("/").join(domain_org)
    dn = handle.query_dn(domain_group_dn)

    if not dn:
        raise UcscOperationError("Get domain group dn",
                                 "Domain Group %s doesn't exist" %
                                 domain_group)
    return domain_group_dn


def domain_assign_to_domaingroup(handle, domain_ip,
                                 domain_group, domain_name=None):
    """
    This method registers Domain to UcsCentral.

    Args:
        handle (UcscHandle): UcsCentral Connection handle
        domain_ip(str): IP of domain, set 'None' if domain_name is valid
        domain_group(string): Full domain_group with root/<org_name>/..
        domain_name(str): Optional Domain name, valid only if domain_ip is None

    Returns:
        None

    Example:
        domain_assign_to_domaingroup(handle, domain_ip="192.168.1.1",
                                     domain_group="root/sample_dom_grp")
    """

    from ucscsdk.mometa.compute.ComputeGroupMembership import\
        ComputeGroupMembership

    domain_group_dn = get_domain_group_dn(handle, domain_group)

    compute_class = handle.query_classid(class_id="ComputeResourceAggrEp")
    compute_dn = compute_class[0].dn

    if domain_ip is None:
        if domain_name is None:
            raise UcscValidationException(
                "Provide either valid domain_ip or domain_name")
        else:
            domain = get_domain(handle, domain_ip=None,
                                domain_name=domain_name)
            domain_ip = domain.address

    domain_assign = ComputeGroupMembership(parent_mo_or_dn=compute_dn,
                                           ip=domain_ip,
                                           group_dn=domain_group_dn)
    handle.set_mo(domain_assign)
    handle.commit()

    return domain_assign



"""This module contains the general information for FabricEtherRef ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FabricEtherRefConsts():
    LC_CTRL_STATE_ALLOCATED = "allocated"
    LC_CTRL_STATE_AVAILABLE = "available"
    LC_CTRL_STATE_DEALLOCATED = "deallocated"
    LC_CTRL_STATE_REPURPOSED = "repurposed"


class FabricEtherRef(ManagedObject):
    """This is FabricEtherRef class."""

    consts = FabricEtherRefConsts()
    naming_props = set([u'name'])

    mo_meta = MoMeta("FabricEtherRef", "fabricEtherRef", "EtherRef-[name]", VersionMeta.Version111a, "InputOutput", 0x3f, [], ["admin", "ext-lan-config", "ext-lan-policy", "ls-network"], [u'adaptorVlan', u'fabricVlan', u'fabricVlanEp', u'fabricVsan', u'fabricVsanEp'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "client_id": MoPropertyMeta("client_id", "clientId", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "lc_ctrl_state": MoPropertyMeta("lc_ctrl_state", "lcCtrlState", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["allocated", "available", "deallocated", "repurposed"], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version111a, MoPropertyMeta.NAMING, 0x8, 1, 256, None, [], []), 
        "oper_eth_dn": MoPropertyMeta("oper_eth_dn", "operEthDn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "clientId": "client_id", 
        "dn": "dn", 
        "lcCtrlState": "lc_ctrl_state", 
        "name": "name", 
        "operEthDn": "oper_eth_dn", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.client_id = None
        self.lc_ctrl_state = None
        self.oper_eth_dn = None
        self.status = None

        ManagedObject.__init__(self, "FabricEtherRef", parent_mo_or_dn, **kwargs)




"""This module contains the general information for MgmtBackupOperation ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class MgmtBackupOperationConsts():
    ADMIN_STATE_DISABLED = "disabled"
    ADMIN_STATE_ENABLED = "enabled"
    PRESERVE_POOLED_VALUES_FALSE = "false"
    PRESERVE_POOLED_VALUES_NO = "no"
    PRESERVE_POOLED_VALUES_TRUE = "true"
    PRESERVE_POOLED_VALUES_YES = "yes"
    PROTO_FTP = "ftp"
    PROTO_HTTP = "http"
    PROTO_NFS_COPY = "nfs-copy"
    PROTO_NONE = "none"
    PROTO_SCP = "scp"
    PROTO_SFTP = "sftp"
    PROTO_TFTP = "tftp"
    REMOTE_BACKUP_OPER_STATE_BACKUP_DELETE = "backup-delete"
    REMOTE_BACKUP_OPER_STATE_BACKUP_NONE = "backup-none"
    TRIGGER_STATUS_TRIGGER_ACKED = "trigger-acked"
    TRIGGER_STATUS_TRIGGER_FAILED = "trigger-failed"
    TRIGGER_STATUS_TRIGGERED = "triggered"
    TRIGGER_STATUS_UNKNOWN = "unknown"
    TYPE_CONFIG_ALL = "config-all"
    TYPE_CONFIG_LOGICAL = "config-logical"
    TYPE_CONFIG_SYSTEM = "config-system"
    TYPE_FULL_STATE = "full-state"


class MgmtBackupOperation(ManagedObject):
    """This is MgmtBackupOperation class."""

    consts = MgmtBackupOperationConsts()
    naming_props = set([])

    mo_meta = MoMeta("MgmtBackupOperation", "mgmtBackupOperation", "remote-oper", VersionMeta.Version131a, "InputOutput", 0x7fff, [], ["admin"], [u'computeSystem'], [u'faultInst'], ["Get", "Set"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["disabled", "enabled"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "hostname": MoPropertyMeta("hostname", "hostname", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, [], []), 
        "last_modified": MoPropertyMeta("last_modified", "lastModified", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "post_action": MoPropertyMeta("post_action", "postAction", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, [], []), 
        "preserve_pooled_values": MoPropertyMeta("preserve_pooled_values", "preservePooledValues", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["false", "no", "true", "yes"], []), 
        "proto": MoPropertyMeta("proto", "proto", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["ftp", "http", "nfs-copy", "none", "scp", "sftp", "tftp"], []), 
        "pwd": MoPropertyMeta("pwd", "pwd", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x80, 0, 64, None, [], []), 
        "remote_backup_oper_state": MoPropertyMeta("remote_backup_oper_state", "remoteBackupOperState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["backup-delete", "backup-none"], []), 
        "remote_error_code": MoPropertyMeta("remote_error_code", "remoteErrorCode", "uint", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "remote_error_descr": MoPropertyMeta("remote_error_descr", "remoteErrorDescr", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "remote_file": MoPropertyMeta("remote_file", "remoteFile", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x200, 1, 128, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x400, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x800, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "trigger_status": MoPropertyMeta("trigger_status", "triggerStatus", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x1000, None, None, None, ["trigger-acked", "trigger-failed", "triggered", "unknown"], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x2000, None, None, None, ["config-all", "config-logical", "config-system", "full-state"], []), 
        "user": MoPropertyMeta("user", "user", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x4000, 0, 510, None, [], []), 
    }

    prop_map = {
        "adminState": "admin_state", 
        "childAction": "child_action", 
        "dn": "dn", 
        "hostname": "hostname", 
        "lastModified": "last_modified", 
        "postAction": "post_action", 
        "preservePooledValues": "preserve_pooled_values", 
        "proto": "proto", 
        "pwd": "pwd", 
        "remoteBackupOperState": "remote_backup_oper_state", 
        "remoteErrorCode": "remote_error_code", 
        "remoteErrorDescr": "remote_error_descr", 
        "remoteFile": "remote_file", 
        "rn": "rn", 
        "status": "status", 
        "triggerStatus": "trigger_status", 
        "type": "type", 
        "user": "user", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.admin_state = None
        self.child_action = None
        self.hostname = None
        self.last_modified = None
        self.post_action = None
        self.preserve_pooled_values = None
        self.proto = None
        self.pwd = None
        self.remote_backup_oper_state = None
        self.remote_error_code = None
        self.remote_error_descr = None
        self.remote_file = None
        self.status = None
        self.trigger_status = None
        self.type = None
        self.user = None

        ManagedObject.__init__(self, "MgmtBackupOperation", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ProcessorQual ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ProcessorQualConsts():
    ARCH_DUAL_CORE_OPTERON = "Dual-Core_Opteron"
    ARCH_INTEL_P4_C = "Intel_P4_C"
    ARCH_OPTERON = "Opteron"
    ARCH_PENTIUM_4 = "Pentium_4"
    ARCH_TURION_64 = "Turion_64"
    ARCH_XEON = "Xeon"
    ARCH_XEON_MP = "Xeon_MP"
    ARCH_ANY = "any"
    MAX_CORES_UNSPECIFIED = "unspecified"
    MAX_PROCS_UNSPECIFIED = "unspecified"
    MAX_THREADS_UNSPECIFIED = "unspecified"
    MIN_CORES_UNSPECIFIED = "unspecified"
    MIN_PROCS_UNSPECIFIED = "unspecified"
    MIN_THREADS_UNSPECIFIED = "unspecified"
    SPEED_UNSPECIFIED = "unspecified"
    STEPPING_UNSPECIFIED = "unspecified"


class ProcessorQual(ManagedObject):
    """This is ProcessorQual class."""

    consts = ProcessorQualConsts()
    naming_props = set([])

    mo_meta = MoMeta("ProcessorQual", "processorQual", "cpu", VersionMeta.Version111a, "InputOutput", 0x3fff, [], ["admin", "pn-policy", "read-only"], [u'computeQual'], [], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "arch": MoPropertyMeta("arch", "arch", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["Dual-Core_Opteron", "Intel_P4_C", "Opteron", "Pentium_4", "Turion_64", "Xeon", "Xeon_MP", "any"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "max_cores": MoPropertyMeta("max_cores", "maxCores", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["unspecified"], ["0-65535"]), 
        "max_procs": MoPropertyMeta("max_procs", "maxProcs", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["unspecified"], ["0-65535"]), 
        "max_threads": MoPropertyMeta("max_threads", "maxThreads", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["unspecified"], ["0-65535"]), 
        "min_cores": MoPropertyMeta("min_cores", "minCores", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["unspecified"], ["0-65535"]), 
        "min_procs": MoPropertyMeta("min_procs", "minProcs", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["unspecified"], ["0-65535"]), 
        "min_threads": MoPropertyMeta("min_threads", "minThreads", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["unspecified"], ["0-65535"]), 
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""[ !#$%\(\)\*\+,\-\./:;\?@\[\\\]\^_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x400, 0, 256, None, [], []), 
        "speed": MoPropertyMeta("speed", "speed", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x800, None, None, None, ["unspecified"], ["0-4294967295"]), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x1000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "stepping": MoPropertyMeta("stepping", "stepping", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x2000, None, None, None, ["unspecified"], ["0-4294967295"]), 
    }

    prop_map = {
        "arch": "arch", 
        "childAction": "child_action", 
        "dn": "dn", 
        "maxCores": "max_cores", 
        "maxProcs": "max_procs", 
        "maxThreads": "max_threads", 
        "minCores": "min_cores", 
        "minProcs": "min_procs", 
        "minThreads": "min_threads", 
        "model": "model", 
        "rn": "rn", 
        "speed": "speed", 
        "status": "status", 
        "stepping": "stepping", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.arch = None
        self.child_action = None
        self.max_cores = None
        self.max_procs = None
        self.max_threads = None
        self.min_cores = None
        self.min_procs = None
        self.min_threads = None
        self.model = None
        self.speed = None
        self.status = None
        self.stepping = None

        ManagedObject.__init__(self, "ProcessorQual", parent_mo_or_dn, **kwargs)

